@@ -1,4 +1,4 @@
-﻿/***************************************************************************
+/***************************************************************************
  *   Copyright (C) 2012 by Santiago González                               *
  *                                                                         *
  ***( see copyright.txt file at root folder )*******************************/
@@ -53,7 +53,7 @@ Circuit::Circuit( qreal x, qreal y, qreal width, qreal height, CircuitView*  par
     m_conStarted = false;
     m_createSubc = false;
     m_acceptKeys = true;
-    m_cicuitChange = 0;
+    m_cicuitBatch = 0;
 
     m_board = NULL;
     m_newConnector = NULL;
@@ -61,7 +61,6 @@ Circuit::Circuit( qreal x, qreal y, qreal width, qreal height, CircuitView*  par
     m_conNumber = 0;
     m_maxUndoSteps = 100;
     m_undoIndex = -1;
-    m_redoIndex = -1;
 
     m_backupPath = MainWindow::self()->getConfigPath("backup.sim1");
     m_hideGrid   = MainWindow::self()->settings()->value( "Circuit/hideGrid" ).toBool();
@@ -78,7 +77,6 @@ Circuit::~Circuit()
 
     m_bckpTimer.stop();
     m_undoStack.clear();
-    m_redoStack.clear();
 
     QFile file( m_backupPath );
     if( !file.exists() ) return;
@@ -122,7 +120,7 @@ QString Circuit::replaceId( QString pinName )
 
 Pin* Circuit::findPin( int x, int y, QString id )
 {
-    /// qDebug() << "Circuit::findPin" << id;
+    // qDebug() << "Circuit::findPin" << id;
     QRectF itemRect = QRectF ( x-4, y-4, 8, 8 );
 
     QList<QGraphicsItem*> list = items( itemRect ); // List of items in (x, y)
@@ -548,10 +546,9 @@ void Circuit::importCirc(  QPointF eventpoint  )
     if( !fileName.isEmpty()
      && (fileName.endsWith(".simu") || fileName.endsWith(".sim1")) )
     {
-        beginCicuitChange();
+        beginUndoStep();
         loadCircuit( fileName );
-        /// clearCircuitState(); // clear all state generated by copy component properties
-        endCicuitChange();
+        endUndoStep();
     }
     m_pasting = false;
 }
@@ -566,7 +563,7 @@ Component* Circuit::createItem( QString type, QString id, bool map )
 
         comp = item->createItemFnPtr()( type, id );
     }
-    if( map) m_compMap[id] = comp;
+    if( map ) m_compMap[id] = comp;
     return comp;
 }
 
@@ -576,7 +573,7 @@ void Circuit::removeItems()                     // Remove Selected items
     m_busy = true;
     if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
 
-    beginCicuitChange(); // Save current state
+    beginUndoStep(); // Save current state
 
     QList<Connector*> conns;
     QList<Component*> comps;
@@ -602,7 +599,7 @@ void Circuit::removeItems()                     // Remove Selected items
         if( comp->itemType() == "Node" ) removeNode( (Node*)comp );
         else                             removeComp( comp );
     }
-    endCicuitChange(); // Calculates created/removed
+    endUndoStep(); // Calculates created/removed
 
     for( QGraphicsItem* item : selectedItems() ) item->setSelected( false );
 
@@ -680,68 +677,74 @@ void Circuit::setChanged()
     if( !title.endsWith('*') ) MainWindow::self()->setWindowTitle(title+'*');
 }
 
-void Circuit::saveState()
+void Circuit::saveChanges()
 {
-    if( m_conStarted || m_circState.size() == 0 ) return;
+    if( m_conStarted || m_circChange.size() == 0 ) return;
     setChanged();
 
-    if( m_undo )
-    {
-        m_redoStack.append( m_circState );
-        m_redoIndex++;
-    }
-    else{                     // Redo or new state
-        if( !m_redo ){
-            if( m_redoStack.size() )
-            {
-                m_redoStack.clear();
-                m_redoIndex = -1;
-                while( m_undoStack.size() > (m_undoIndex+1) ) m_undoStack.removeLast();
-            }
-            m_undoStack.append( m_circState );
-            if( m_undoStack.size() > m_maxUndoSteps )
-            {
-                m_undoStack.takeFirst();
-                m_undoIndex--;
-            }
-        }
-        m_undoIndex++;
-    }
-    clearCircuitState();
-    m_cicuitChange = 0;  // Ends all CicuitChanges
+    while( m_undoStack.size() > (m_undoIndex+1) ) m_undoStack.removeLast();
 
-    // clear Removed Comps;
+    m_undoStack.append( m_circChange );
+    if( m_undoStack.size() > m_maxUndoSteps )
+    {
+        m_undoStack.takeFirst();
+        m_undoIndex--;
+    }
+    m_undoIndex++;
+
+    clearCircChanges();
+    m_cicuitBatch = 0;  // Ends all CicuitChanges
+
+    deleteRemoved(); // Delete Removed Components;
+
+    /// qDebug() << "Circuit::saveChanges ---------------------------"<<m_undoIndex<<m_undoStack.size()<<endl;
+}
+
+void Circuit::deleteRemoved()
+{
     for( CompBase* comp : m_removedComps ) delete comp;
     m_removedComps.clear();
 }
 
-void Circuit::unSaveState()
+void Circuit::removeLastUndo()
 {
     if( m_undoStack.isEmpty() ) return;
     m_undoStack.takeLast();
     m_undoIndex--;
 }
 
-void Circuit::beginCicuitModify() // Don't create/remove
+void Circuit::beginCircuitBatch() // Don't create/remove
 {
-    //qDebug() << "Circuit::beginCicuitModify";
-    if( !m_cicuitChange ) clearCircuitState();
-    m_cicuitChange++;
+    /// qDebug() << "Circuit::beginCircuitBatch";
+    if( !m_cicuitBatch ) clearCircChanges();
+    m_cicuitBatch++;
 }
 
-void Circuit::endCicuitModify() // Don't create/remove
+void Circuit::endCircuitBatch() // Don't create/remove
 {
-    //qDebug() << "Circuit::endCicuitModify";
-    if( m_cicuitChange > 0 ){
-        m_cicuitChange--;
-        if( m_cicuitChange == 0 ) saveState();
+    /// qDebug() << "Circuit::endCircuitBatch";
+    if( m_cicuitBatch > 0 ){
+        m_cicuitBatch--;
+        if( m_cicuitBatch == 0 ) saveChanges();
     }
 }
 
-void Circuit::beginCicuitChange() // Save current state
+void Circuit::cancelUndoStep()
 {
-    //qDebug() << "Circuit::beginCicuitChange";
-    beginCicuitModify();
+    calcCircuitChanges();
+    if( m_circChange.size() )
+    {
+        endCircuitBatch();
+        undo();
+        m_undoStack.takeLast();
+    }
+    else m_cicuitBatch = 0;
+    /// qDebug() << "Circuit::cancelUndoStep--------------------------------"<<endl;
+}
+
+void Circuit::beginUndoStep() // Save current state
+{
+    beginCircuitBatch();
 
     m_oldConns = m_connList;
     m_oldComps = m_compList;
@@ -754,139 +757,85 @@ void Circuit::beginCicuitChange() // Save current state
     for( Component* comp : m_oldComps ) m_compStrMap.insert( comp, comp->toString() );
 }
 
-void Circuit::endCicuitChange()   // Calculates created/removed
+void Circuit::endUndoStep()   //
 {
-    //qDebug() << "Circuit::endCicuitChange  Removed";
+    calcCircuitChanges();
+    endCircuitBatch();
+}
+
+void Circuit::calcCircuitChanges()   // Calculates created/removed
+{
+    /// qDebug() << "Circuit::calcCicuitChanges Removed:";
     // Items Removed
-    for( Connector* conn : m_oldConns-m_connList ) addCompState( conn->getUid(), COMP_STATE_REMOVED, m_compStrMap.value(conn) );
-    for( Node*      node : m_oldNodes-m_nodeList ) addCompState( node->getUid(), COMP_STATE_REMOVED, m_compStrMap.value(node) );
-    for( Component* comp : m_oldComps-m_compList ) addCompState( comp->getUid(), COMP_STATE_REMOVED, m_compStrMap.value(comp) );
-    //qDebug() << "Circuit::endCicuitChange  Created";
+    for( Connector* conn : m_oldConns-m_connList ) addCompChange( conn->getUid(), COMP_STATE_NEW, m_compStrMap.value(conn) );
+    for( Node*      node : m_oldNodes-m_nodeList ) addCompChange( node->getUid(), COMP_STATE_NEW, m_compStrMap.value(node) );
+    for( Component* comp : m_oldComps-m_compList ) addCompChange( comp->getUid(), COMP_STATE_NEW, m_compStrMap.value(comp) );
+    /// qDebug() << "Circuit::calcCicuitChanges Created:";
     // Items Created
-    for( Component* comp : m_compList-m_oldComps ) addCompState( comp->getUid(), COMP_STATE_CREATED, "" );
-    for( Node*      node : m_nodeList-m_oldNodes ) addCompState( node->getUid(), COMP_STATE_CREATED, "" );
-    for( Connector* conn : m_connList-m_oldConns ) addCompState( conn->getUid(), COMP_STATE_CREATED, "" );
-    //qDebug() << "Circuit::endCicuitChange  Done";
-    endCicuitModify();
+    for( Component* comp : m_compList-m_oldComps ) addCompChange( comp->getUid(), COMP_STATE_NEW, "" );
+    for( Node*      node : m_nodeList-m_oldNodes ) addCompChange( node->getUid(), COMP_STATE_NEW, "" );
+    for( Connector* conn : m_connList-m_oldConns ) addCompChange( conn->getUid(), COMP_STATE_NEW, "" );
 }
 
-void Circuit::saveCompState( QString name, QString property, QString value )
+void Circuit::saveCompChange( QString component, QString property, QString undoVal )
 {
-    clearCircuitState();
-    addCompState( name, property, value );
-    saveState();
+    clearCircChanges();
+    addCompChange( component, property, undoVal );
+    saveChanges();
 }
 
-void Circuit::addCompState( QString name, QString property, QString value )
+void Circuit::addCompChange( QString component, QString property, QString undoVal )
 {
     if( m_loading || m_deleting ) return;
-    //qDebug() << "Circuit::addCompState    " << name << property;// << value;
+    /// qDebug() << "Circuit::addCompChange      " << component << property;// << value;
 
-    compState cState{ name, property, value };
+    compChange cChange{ component, property, undoVal, "" };
 
-    if ( m_undo ) m_circState.compStates.prepend( cState );
-    else          m_circState.compStates.append( cState );
+    m_circChange.compChanges.append( cChange );
 }
 
-bool Circuit::restoreState( circState step )
+void Circuit::restoreState()
 {
     if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
     m_busy = true;
 
-    clearCircuitState();
+    circChange& step = m_undoStack[ m_undoIndex ];
 
     int iStep, i;
-    if( m_undo ) { iStep = -1; i = step.compStates.size()-1; }
+    if( m_undo ) { iStep = -1; i = step.compChanges.size()-1; }
     else         { iStep =  1; i = 0; }
 
-    while( i>=0 && i < step.compStates.size() )
+    while( i>=0 && i < step.compChanges.size() )
     {
-        compState cState = step.compStates[i];
+        compChange* cChange = &step.compChanges[i];
         i += iStep;
-        QString compName = cState.component;
-        QString propName = cState.property;
-        QString propVal  = cState.valStr;
-        CompBase* comp   = m_compMap.value( compName );
+        QString propName   = cChange->property;
+        QString propVal    = m_undo ? cChange->undoValue : cChange->redoValue;
+        CompBase* comp     = m_compMap.value( cChange->component );
 
-//qDebug() << "Circuit::restoreState -->"<< compName << propName << comp;
+    /// qDebug() << "Circuit::restoreState"<< cChange->component << propName << comp;
 
-        if( propName == COMP_STATE_REMOVED )       // Create Item
+        if( propName == COMP_STATE_NEW )                       // Create/Remove Item
         {
-            loadStrDoc( propVal );
-            if( m_newComp ) addCompState( m_newComp->getUid(), COMP_STATE_CREATED, "" );
-        }
-        else if( propName == COMP_STATE_CREATED )  // Remove Item
-        {
-            if( !comp ) continue;
-            addCompState( comp->getUid(), COMP_STATE_REMOVED, comp->toString() );
+            if( propVal.isEmpty() )               // Remove item
+            {
+                if( !comp ) continue;
+                if( m_undo && cChange->redoValue.isEmpty() ) cChange->redoValue = comp->toString();
 
-            if     ( comp->itemType() == "Connector" ) removeConnector( (Connector*)comp );
-            else if( comp->itemType() == "Node"      ) removeNode( (Node*)comp );
-            else                                       removeComp( (Component*)comp );
+                if     ( comp->itemType() == "Connector" ) removeConnector( (Connector*)comp );
+                else if( comp->itemType() == "Node"      ) removeNode( (Node*)comp );
+                else                                       removeComp( (Component*)comp );
+            }
+            else loadStrDoc( propVal );           // Create Item
         }
-        else {                            // Property
-            if( !comp ) continue;
-            addCompState( compName, propName, comp->getPropStr( propName ) );
-            comp->setPropStr( propName, propVal );
+        else if( comp )
+        {
+            if( m_undo && cChange->redoValue.isEmpty() ) cChange->redoValue = comp->getPropStr( propName );
+            comp->setPropStr( propName, propVal ); // Property
         }
     }
-    saveState();
-
-    m_LdPinMap.clear();
     m_busy = false;
-    update();
-    return true;
-}
-
-void Circuit::undo()
-{
-    if( m_busy || m_deleting || m_conStarted || m_undoIndex < 0 ) return;
-
-//qDebug() << "\nCircuit::undo"<<m_undoIndex<<m_redoIndex;
-
-    if( m_undoIndex > m_undoStack.size() )
-    {
-        qDebug() << "Circuit::redo index Error"<< m_undoStack.size()<<m_undoIndex;
-        clearUndoRedo();
-        return;
-    }
-    m_undo = true;
-    circState step = m_undoStack.at( m_undoIndex );
-    if( restoreState( step ) )
-    {
-        m_undoIndex--;
-        finishUndoRedo();
-    }
-    else clearUndoRedo();
-    m_undo = false;
-}
-
-void Circuit::redo()
-{
-    if( m_busy || m_deleting || m_conStarted || m_redoIndex < 0 ) return;
-
-//qDebug() << "\nCircuit::redo"<<m_undoIndex<<m_redoIndex;
-
-    if( m_redoIndex > m_redoStack.size() )
-    {
-        qDebug() << "Circuit::redo index Error"<< m_redoStack.size()<<m_redoIndex;
-        clearUndoRedo();
-        return;
-    }
-    m_redo = true;
-    circState step = m_redoStack.at( m_redoIndex );
-    if( restoreState( step ) )
-    {
-        m_redoIndex--;
-        finishUndoRedo();
-        if( m_redoIndex < 0 ) m_redoStack.clear(); /// ???
-    }
-    else clearUndoRedo();
-    m_redo = false;
-}
-
-void Circuit::finishUndoRedo()
-{
+    deleteRemoved(); // Delete Removed Components;
     for( Connector* con : m_connList ) {
         if( m_board && m_board->m_boardMode ) con->setVisib( false );
         else{
@@ -894,16 +843,27 @@ void Circuit::finishUndoRedo()
             con->endPin()->isMoved();
         }
     }
+    update();
 }
 
-void Circuit::clearUndoRedo()
+void Circuit::undo()
 {
-    qDebug() << "Circuit::clearUndoRedo Warning: Stack Cleared"<<m_redoIndex<<m_undoIndex<<"\n";
-    m_redoStack.clear();
-    m_undoStack.clear();
-    m_redoIndex = -1;
-    m_undoIndex = -1;
-    m_busy = false;
+    if( m_busy || m_deleting || m_conStarted || m_undoIndex < 0 ) return;
+/// qDebug() << "\nCircuit::undo"<<m_undoIndex<<m_undoStack.size();
+    m_undo = true;
+    restoreState();
+    m_undoIndex--;
+    m_undo = false;
+}
+
+void Circuit::redo()
+{
+    if( m_busy || m_deleting || m_conStarted || m_undoIndex >= (m_undoStack.size()-1) ) return;
+    m_redo = true;
+    m_undoIndex++;
+/// qDebug() << "\nCircuit::redo"<<m_undoIndex<<m_undoStack.size();
+    restoreState();
+    m_redo = false;
 }
 
 void Circuit::copy( QPointF eventpoint )
@@ -931,7 +891,7 @@ void Circuit::copy( QPointF eventpoint )
     }   }
     QString circuit;
     for( CompBase* comp : complist ) circuit += comp->toString();
-    for( CompBase* con :  conlist )  circuit += con->toString();
+    for( CompBase* con  :  conlist ) circuit += con->toString();
 
     QApplication::clipboard()->setText( circuit );
 }
@@ -941,30 +901,25 @@ void Circuit::paste( QPointF eventpoint )
     if( m_conStarted ) return;
     if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
 
-    bool animate = m_animate;
     m_busy    = true;
     m_pasting = true;
     for( QGraphicsItem*item : selectedItems() ) item->setSelected( false );
 
     m_deltaMove = toGrid(eventpoint) - m_eventpoint;
 
-    QString circuit = circuitHeader();
-    circuit += QApplication::clipboard()->text();
-    circuit += "\n</circuit>";
+    QString circuit = QApplication::clipboard()->text();
 
-    beginCicuitChange();
+    beginUndoStep();
     loadStrDoc( circuit );
-    /// clearCircuitState(); // ??? clear all state generated by copy component properties
-    endCicuitChange();
+    endUndoStep();
 
-    setAnimate( animate );
     m_pasting = false;
     m_busy = false;
 }
 
 void Circuit::newconnector( Pin* startpin, bool save )
 {
-    if( save ) beginCicuitChange();
+    if( save ) beginUndoStep();
 
     m_conStarted = true;
 
@@ -983,7 +938,7 @@ void Circuit::closeconnector( Pin* endpin, bool save )
 {
     m_conStarted = false;
     m_newConnector->closeCon( endpin );
-    if( save ) endCicuitChange();
+    if( save ) endUndoStep();
 }
 
 void Circuit::deleteNewConnector()
@@ -991,7 +946,8 @@ void Circuit::deleteNewConnector()
     if( !m_conStarted ) return;
     removeConnector( m_newConnector );
     m_conStarted = false;
-    unSaveState();
+
+    cancelUndoStep();
 }
 
 void Circuit::updateConnectors()
@@ -1040,8 +996,10 @@ void Circuit::mousePressEvent( QGraphicsSceneMouseEvent* event )
 {
     if( event->button() == Qt::LeftButton )
     {
-        if( m_conStarted )  event->accept();
+        if( m_conStarted ) event->accept();
         QGraphicsScene::mousePressEvent( event );
+
+        if( !event->isAccepted() ) Linkable::stopLinking(); // Click in empty place
     }
     else if( event->button() == Qt::RightButton )
     {
@@ -1082,7 +1040,6 @@ void Circuit::keyPressEvent( QKeyEvent* event )
         QGraphicsScene::keyPressEvent( event );
         return;
     }
-
     int key = event->key();
 
     if( m_conStarted )
@@ -1091,6 +1048,11 @@ void Circuit::keyPressEvent( QKeyEvent* event )
         else QGraphicsScene::keyPressEvent( event );
         return;
     }
+    if( key == Qt::Key_Escape )
+    {
+        Linkable::stopLinking();
+        return;
+    }
     if( event->modifiers() & Qt::AltModifier ) // Create Component shortcut
     {
         QString str = event->text();
@@ -1112,7 +1074,7 @@ void Circuit::keyPressEvent( QKeyEvent* event )
                 enterItem->setPos( toGrid( CircuitView::self()->mapToScene( cPos ) ) );
                 addItem( enterItem );
                 m_compList.insert( enterItem );
-                saveCompState( enterItem->getUid(), COMP_STATE_CREATED, "" );
+                saveCompChange( enterItem->getUid(), COMP_STATE_NEW, "" );
             }
         }
     }
@@ -1217,7 +1179,7 @@ void Circuit::dropEvent( QGraphicsSceneDragDropEvent* event )
                 enterItem->setBackground( file );
                 addItem( enterItem );
                 m_compList.insert( enterItem );
-                saveCompState( enterItem->getUid(), COMP_STATE_CREATED, "" );
+                saveCompChange( enterItem->getUid(), COMP_STATE_NEW, "" );
         }   }
         else CircuitWidget::self()->loadCirc( id );
 }   }
