@@ -13,8 +13,7 @@
 #include "connector.h"
 #include "pin.h"
 
-#define COMP_STATE_REMOVED "__COMP_STATE_REMOVED__"
-#define COMP_STATE_CREATED "__COMP_STATE_CREATED__"
+#define COMP_STATE_NEW "__COMP_STATE_NEW__"
 
 enum stateMode{
     stateNew = 1,
@@ -62,14 +61,16 @@ class MAINMODULE_EXPORT Circuit : public QGraphicsScene
         void clearCircuit();
 
         //--- Undo/Redo ----------------------------------
-        void saveState();
-        void unSaveState();
-        void addCompState( QString name, QString property, QString value  );
-        void saveCompState( QString name, QString property, QString value );
-        void beginCicuitModify();
-        void endCicuitModify();
-        void beginCicuitChange(); // Does create/remove
-        void endCicuitChange();   // Does create/remove
+        void saveChanges();
+        void removeLastUndo();
+        void addCompChange(  QString component, QString property, QString undoVal );
+        void saveCompChange( QString component, QString property, QString undoVal );
+        void beginCircuitBatch();
+        void endCircuitBatch();
+        void calcCircuitChanges(); // Calculate total changes
+        void cancelUndoStep();     // Revert changes done
+        void beginUndoStep();      // Record current state
+        void endUndoStep();        // Does create/remove
         bool undoRedo() { return m_undo || m_redo; }
         //------------------------------------------------
 
@@ -148,28 +149,29 @@ class MAINMODULE_EXPORT Circuit : public QGraphicsScene
  static Circuit*  m_pSelf;
 
         //--- Undo/Redo ----------------------------------
-        struct compState{       // Component State to be restored by Undo/Redo
-            QString component;
-            QString property;
-            QString valStr;
+        struct compChange{      // Component Change to be performed by Undo/Redo to complete a Circuit change
+            QString component;  // Component name
+            QString property;   // Property name
+            QString undoValue;  // Property value for Undo step
+            QString redoValue;  // Property value for Redo step
         };
-        struct circState{       // Circuit State to be restored by Undo/Redo
-            QList<compState> compStates;
-            int size() { return compStates.size(); }
-            void clear() { compStates.clear(); }
+        struct circChange{       // Circuit Change to be performed by Undo/Redo to restore circuit state
+            QList<compChange> compChanges;
+            int size() { return compChanges.size(); }
+            void clear() { compChanges.clear(); }
         };
 
-        inline void clearCircuitState() { m_circState.clear(); }
-        bool restoreState( circState step );
-        void clearUndoRedo();
-        void finishUndoRedo();
+        inline void clearCircChanges() { m_circChange.clear(); }
+        void deleteRemoved();
+        void restoreState();
 
-        QSet<CompBase*> m_removedComps; // removed component list;
+        int m_maxUndoSteps;
+        int m_undoIndex;
 
-        circState m_circState;
-        QList<circState> m_undoStack;
-        QList<circState> m_redoStack;
+        circChange m_circChange;
+        QList<circChange> m_undoStack;
 
+        QSet<CompBase*>  m_removedComps; // removed component list;
         QSet<Connector*> m_oldConns;
         QSet<Component*> m_oldComps;
         QSet<Node*>      m_oldNodes;
@@ -194,9 +196,6 @@ class MAINMODULE_EXPORT Circuit : public QGraphicsScene
         int m_seqNumber;
         int m_conNumber;
         int m_error;
-        int m_maxUndoSteps;
-        int m_undoIndex;
-        int m_redoIndex;
 
         bool m_pasting;
         bool m_deleting;
@@ -212,7 +211,7 @@ class MAINMODULE_EXPORT Circuit : public QGraphicsScene
         bool m_redo;
         bool m_acceptKeys;
         bool m_createSubc;
-        int m_cicuitChange;
+        int m_cicuitBatch;
 
         QPointF m_eventpoint;
         QPointF m_deltaMove;
