@@ -101,7 +101,7 @@ void CircuitView::dragEnterEvent( QDragEnterEvent* event )
         m_enterItem->setPos( mapToScene( event->pos() ) );
         m_circuit->addItem( m_enterItem );
         m_circuit->compList()->insert( m_enterItem );
-        m_circuit->saveCompState( m_enterItem->getUid(), COMP_STATE_CREATED, "" );
+        m_circuit->saveCompChange( m_enterItem->getUid(), COMP_STATE_NEW, "" );
         this->setFocus();
     }
 }
@@ -118,7 +118,7 @@ void CircuitView::dragLeaveEvent( QDragLeaveEvent* event )
     if( !m_enterItem ) return;
 
     m_circuit->removeComp( m_enterItem );
-    Circuit::self()->unSaveState();
+    Circuit::self()->removeLastUndo();
     m_enterItem = NULL;
 }
 
@@ -131,9 +131,16 @@ void CircuitView::mousePressEvent( QMouseEvent* event )
      && event->modifiers() & Qt::ShiftModifier
      && !m_circuit->is_constarted() )
     {
-        itemAt( event->pos() )->setSelected( false );
-        m_mousePressPos = event->pos();
-        m_waitForDragStart = true;
+        QGraphicsItem* item = itemAt( event->pos() );
+        if( item )                                                  // Check if item exists before start drag:
+        {
+            while ( item->parentItem() ) item = item->parentItem(); // Make sure the item deselected is the top graphic item.
+
+            if( !item->isSelected() ) m_circuit->clearSelection();  // If the comp is not selected when drag starts, clear all the selections.
+            item->setSelected( false );
+            m_mousePressPos = event->pos();
+            m_waitForDragStart = true;
+        }
     }
     else if( event->button() == Qt::MidButton )
     {
@@ -160,9 +167,9 @@ void CircuitView::mouseMoveEvent( QMouseEvent* event )
          && !m_circuit->selectedItems().isEmpty() )
         {
             event->accept();
-            m_circuit->beginCicuitModify(); /// FIXME UNDOREDO
-            m_circuit->copy( m_mousePressPos );
-            m_circuit->paste( event->pos() );
+            m_circuit->beginCircuitBatch();     // Add this to force paste() to not save changes
+            m_circuit->copy( m_mousePressPos ); // Component move after paste() will save changes
+            m_circuit->paste( event->pos() );   // paste() will call beginUndoStep()
         }
     }
     QGraphicsView::mouseMoveEvent( event );
@@ -191,19 +198,16 @@ void CircuitView::overrideCursor( const QCursor &cursor )
 
 void CircuitView::contextMenuEvent( QContextMenuEvent* event )
 {
+    if( Linkable::m_selecComp ){ // Cancel link to components
+        Linkable::stopLinking();
+        return;
+    }
     QGuiApplication::restoreOverrideCursor();
     QGraphicsView::contextMenuEvent( event );
 
     if( m_circuit->is_constarted() ) m_circuit->deleteNewConnector();
     else if( !event->isAccepted() )
     {
-        if( Component::m_selecComp ) // Cancel link to components
-        {
-            Component::m_selecComp->compSelected( NULL );
-            Component::m_selecComp = NULL;
-            return;
-        }
-
         QPointF eventPos = mapToScene( event->globalPos() ) ;
         m_eventpoint = mapToScene( event->pos()  );
 
