@@ -49,9 +49,11 @@ Bus::Bus( QString type, QString id )
     m_busPin0->setIsBus( true );
 
     addPropGroup( { tr("Main"), {
-new IntProp<Bus>("Num_Bits" , tr("Size")     ,"_Bits", this, &Bus::numLines, &Bus::setNumLines,0,"uint" ),
-new IntProp<Bus>("Start_Bit", tr("Start Bit"),""     , this, &Bus::startBit, &Bus::setStartBit,0,"uint" )
-    },groupNoCopy} );
+new IntProp<Bus>("Num_Bits" , tr("Size"),"_Bits", this
+                , &Bus::numLines, &Bus::setNumLines, propNoCopy,"uint" ),
+
+new IntProp<Bus>("Start_Bit", tr("Start Bit"),"", this, &Bus::startBit, &Bus::setStartBit,0,"uint" )
+    }, groupNoCopy } );
 }
 Bus::~Bus(){}
 
