@@ -17,7 +17,7 @@ class QSignalMapper;
 class MAINMODULE_EXPORT Esp01 : public Component, public UsartModule, public eElement
 {
     public:
-        Esp01( QObject* parent, QString type, QString id );
+        Esp01( QString type, QString id );
         ~Esp01();
 
         enum espAction_t{
@@ -28,7 +28,7 @@ class MAINMODULE_EXPORT Esp01 : public Component, public UsartModule, public eEl
             uartReply
         };
 
-        static Component* construct( QObject* parent, QString type, QString id );
+        static Component* construct( QString type, QString id );
         static LibraryItem* libraryItem();
 
         int baudrate() { return m_baudrate; }
