@@ -6,6 +6,7 @@
 #include <QInputDialog>
 
 #include "tunnel.h"
+#include "linkable.h"
 #include "itemlibrary.h"
 #include "propdialog.h"
 #include "circuitwidget.h"
@@ -252,8 +253,8 @@ QRectF Tunnel::boundingRect() const
 
 void Tunnel::mousePressEvent( QGraphicsSceneMouseEvent* event )
 {
-    if( !m_selecComp )  // Used when linking or creating Boards to set this as main component
-        Component::mousePressEvent( event );
+    if( !Linkable::m_selecComp )  // Used when linking or creating Boards to set this as main component
+        Component::mousePressEvent( event ); // Tunnel should not be linked or main component
 }
 
 void Tunnel::paint( QPainter* p, const QStyleOptionGraphicsItem *option, QWidget *widget )
