@@ -13,7 +13,7 @@
 class MAINMODULE_EXPORT Hd44780_Base : public Component
 {
     public:
-        Hd44780_Base( QObject* parent, QString type, QString id );
+        Hd44780_Base( QString type, QString id );
         ~Hd44780_Base();
 
         int cols() { return m_cols; }
