@@ -313,7 +313,7 @@ void Transformer::create( winding_t* w  )
     QList<Pin*>*   pins  = &w->pins;
     QList<eCoil*>* coils = &w->coils;
 
-    for( Pin* pin : *pins ) { pin->removeConnector(); m_signalPin.removeAll( pin ); delete pin; }
+    for( Pin* pin : *pins ) deletePin( pin );
     pins->clear();
     for( eCoil* coil : *coils ) delete coil;
     coils->clear();
