@@ -11,7 +11,7 @@
 class MAINMODULE_EXPORT ThermistorBase : public VarResBase
 {
     public:
-        ThermistorBase( QObject* parent, QString type, QString id );
+        ThermistorBase( QString type, QString id );
         ~ThermistorBase();
 
         bool ptc()  { return m_ptc; }
