@@ -109,7 +109,7 @@ void Chip::initChip()
         m_height  = root.attribute( "height" ).toInt();
         m_area = QRect( 0, 0, 8*m_width, 8*m_height );
 
-        for( Pin* pin : m_unusedPins ) deletePin( pin );
+        for( Pin* pin : m_unusedPins ) if( pin ) deletePin( pin );
         m_unusedPins.clear();
         m_ePin.clear();
         m_pin.clear();
@@ -195,15 +195,6 @@ void Chip::addNewPin( QString id, QString type, QString label, int pos, int xpos
     }
 }
 
-void Chip::deletePin( Pin* pin )
-{
-    if( !pin ) return;
-
-    pin->removeConnector();
-    m_signalPin.removeAll( pin );
-    delete pin;
-}
-
 void Chip::setLogicSymbol( bool ls )
 {
     if( m_initialized && (m_isLS == ls) ) return;
