@@ -17,14 +17,16 @@ class InfoWidget : public QWidget, private Ui::infoWidget
     public:
         InfoWidget( QWidget* parent=0 );
 
-        void setRate( double rate , int load );
+ static InfoWidget* self() { return m_pSelf; }
+
+        void setRate( double rate=0, double simLoad=0, double guiLoad=0 );
         void setCircTime( uint64_t tStep );
         void setTargetSpeed( double s );
 
     public slots:
 
     private:
-
+ static InfoWidget* m_pSelf;
 };
 
 #endif
